@@ -6,7 +6,7 @@ require URI::WithBase;
 use strict;
 use vars qw(@EXPORT $VERSION);
 
-$VERSION = "5.02";
+$VERSION = "5.04";
 
 # Provide as much as possible of the old URI::URL interface for backwards
 # compatibility...
@@ -105,7 +105,7 @@ sub eparams
 {
     my $self = shift;
     my @p = $self->path_segments;
-    return unless ref($p[-1]);
+    return undef unless ref($p[-1]);
     @p = @{$p[-1]};
     shift @p;
     join(";", @p);
@@ -144,7 +144,7 @@ sub query {
 		Carp::croak("$mess (you must call equery)");
 	    }
 	}
-	# Now it should be safe to unescape the string without loosing
+	# Now it should be safe to unescape the string without losing
 	# information
 	return uri_unescape($old);
     }
@@ -202,7 +202,7 @@ This module is provided for backwards compatibility with modules that
 depend on the interface provided by the C<URI::URL> class that used to
 be distributed with the libwww-perl library.
 
-The following differences compared to the C<URI> class interface exist:
+The following differences exist compared to the C<URI> class interface:
 
 =over 3
 
@@ -213,11 +213,12 @@ constructor interface.
 
 =item *
 
-The constructor takes an optional $base argument.  See L<URI::WithBase>.
+The constructor takes an optional $base argument.  The C<URI::URL>
+class is a subclass of C<URI::WithBase>.
 
 =item *
 
-The URI::URL->newlocal class method is the same as URI::file->new_abs
+The URI::URL->newlocal class method is the same as URI::file->new_abs.
 
 =item *
 
@@ -233,15 +234,15 @@ $url->crack method
 
 =item *
 
-$url->full_path; same as ($uri->abs_path || "/")
+$url->full_path: same as ($uri->abs_path || "/")
 
 =item *
 
-$url->netloc; same as $uri->authority
+$url->netloc: same as $uri->authority
 
 =item *
 
-$url->epath, $url->equery; same as $uri->path, $uri->query
+$url->epath, $url->equery: same as $uri->path, $uri->query
 
 =item *
 
@@ -249,12 +250,12 @@ $url->path and $url->query pass unescaped strings.
 
 =item *
 
-$url->path_components; same as $uri->path_segments (if you don't
-consider path segment parameters).
+$url->path_components: same as $uri->path_segments (if you don't
+consider path segment parameters)
 
 =item *
 
-$url->params and $url->eparams methods.
+$url->params and $url->eparams methods
 
 =item *
 
@@ -267,27 +268,27 @@ L<URI::WithBase>.
 
 =item *
 
-$url->frag; same as $uri->fragment
+$url->frag: same as $uri->fragment
 
 =item *
 
-$url->keywords; same as $uri->query_keywords;
+$url->keywords: same as $uri->query_keywords
 
 =item *
 
-$url->localpath with friends map to $uri->file
+$url->localpath and friends map to $uri->file.
 
 =item *
 
-$url->address and $url->encoded822addr; same as $uri->to for mailto URI.
+$url->address and $url->encoded822addr: same as $uri->to for mailto URI
 
 =item *
 
-$url->groupart method for news URI.
+$url->groupart method for news URI
 
 =item *
 
-$url->article; same as $uri->message
+$url->article: same as $uri->message
 
 =back
 
